/**
 * JTableTest
 */
package it.mokabyte.appdesktop.jtable;

import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.TableColumn;

/**
 * Programma di prova per verificare il funzionamento degli
 * editor di cella con il componente JTable
 * 
 * @author max
 */
public class JTableTest {

	/** elenco utenti */
	String[] utenti = { "Max", "Giovanni", "Andrea", "Marco" };
	
	/** elenco dei gruppi relativi agli utenti */
	String[] gruppi = { "user", "supervisor", "user", "user" };
	
	/** elenco dei possibli valori per i gruppi */
	String[] suggestions = { "user", "guest", "poker", "poweruser", 
			"supervisor", "god" };
	
	/**
	 * Crea questo oggetto
	 */
	public JTableTest() {
		
		/*
		 * Modello dati di prova utilizzato dalla tabella
		 */
		AbstractTableModel model = new AbstractTableModel() {
			
			/**
			 * I nomi delle colonne sono fissi
			 * @return nome della colonna richiesta
			 */
			public String getColumnName(int col) {
				switch( col ) {
				case 0:
					return "Nome utente";
				case 1:
					return "Gruppo di appartenenza";
				}
				return "";
			}

			/**
			 * @return il numero di righe  calcolato sulla base dell'elenco degli utenti
			 */
			public int getRowCount() {
				return utenti.length;
			}

			/**
			 * @return numero di colonne (fisso 2)
			 */
			public int getColumnCount() {
				return 2;
			}

			/**
			 * Questo metodo ritorna un valore booleano che indica se la
			 * cella  editabile. In questo specifico esempio  modificabile
			 * solo al seconda colonna.
			 * 
			 * @return true se la cella  editabile
			 */
			public boolean isCellEditable(int row, int col) {
				return (col == 1);
			}

			/**
			 * Ottiene il valore di una cella, estraendo i dati direttamente
			 * dai vettori utenti e gruppi.
			 * 
			 * @return valore della cella
			 */
			public Object getValueAt(int row, int col) {
				switch( col ) {
				case 0:
					return utenti[ row ];
				case 1:
					return gruppi[ row ];
				}
				return "";
			}

			/**
			 * Imposta il valore della cella, indispensabile per modificare
			 * i dati alla base del modello e vedere effettivamente
			 * applicate le modifiche inserite in fase di modifica delle
			 * celle.
			 */
			public void setValueAt(Object value, int row, int col) {
				gruppi[ row ] = (String)value;
			}
			
		};
		
		//crea la tabella
		JTable table = new JTable(model);
		
		//ottiene un oggetto che rappresenta una colonna ed imposta
		//l'editor personalizzato
		TableColumn tb = table.getColumnModel().getColumn(1);
		tb.setCellEditor( new AutocompletingCellEditor(suggestions) );
		
		//crea una finestra di prova all'interno della quale inserisce
		//la tabella appena creata
		JFrame frame = new JFrame("Test JTable");
		frame.getContentPane().add(new JScrollPane(table));
		frame.pack();
		frame.setVisible(true);
	}
	
	/**
	 * 
	 */
	public static void main(String[] args) {
		new JTableTest();
	}

}
